import { AuthServiceService } from './../../../shared/auth-service.service';
import { Location } from '@angular/common';
import { Component, OnInit, ViewChild } from '@angular/core';
import { Router, ActivatedRoute, Params } from '@angular/router';
import { EventService } from '../../../shared/event.service';
import { UserService } from '../../../shared/user.service';
import { ToastrService } from 'ngx-toastr';
import { NgxSpinnerService } from 'ngx-spinner';
import { FormGroup, NgForm } from '@angular/forms';

@Component({
  selector: 'app-add-event',
  templateUrl: './add-event.component.html',
  styleUrls: ['./add-event.component.css']
})


export class AddEventComponent implements OnInit {
 
  @ViewChild('f') eventForm: NgForm;
  typeMode: boolean = false;
  typeLink: string = '';
  eventId: number;
  bindingDateSplit;
  higriDateVal:string;
  checkSaveClick:boolean = false;

  event = {
    employee_name: '',
    employee_name_en: '',
    name: '',
    name_en: '',
    ranking: '',
    display_location: '',
    type: '',
    status: '',
    time: '',
  }

  constructor(private eventService: EventService,
    private userService: UserService,
    private location: Location,
    private toastr: ToastrService,
    private authSer: AuthServiceService,
    private route: ActivatedRoute, 
    private spineer: NgxSpinnerService) { }

  ngOnInit() {
    
    //show / hide notification search in header
    this.authSer.notificationLogin = true;
    this.authSer.showSearchHeader = false;
    this.authSer.showHeaderLogin = false;
    this.authSer.showHeaderDashBoard = true;
    this.authSer.showDashboardHeader = true;
    this.authSer.internalHeader = false;
    
    this.event.status = '1';

    this.route.params.subscribe(
      (params: Params) => {
        if(params['typeEventMode'] == 'edit') {
          this.typeLink = 'تعديل';
          this.spineer.show();
          this.typeMode = true;
          this.eventId = params['editEventId'];
          this.eventService.getEventData(this.eventId).subscribe(
            (responce) => {
              console.log(responce);
              const eventData = responce['event'][0];
              console.log(eventData);
              this.event.name = eventData.name;
              this.event.name_en = eventData.name_en;
              this.event.ranking = eventData.ranking;
              this.event.display_location = eventData.display_location;
              this.event.type = eventData.type;
              this.event.status = eventData.status;
              const dateTime = eventData.event_time.split(' ');
              this.event.time = dateTime[1];
              this.bindingDateSplit = dateTime[0];
              this.spineer.hide();
            },
            (error) => {
              console.log(error);
            }
          )
        } else {
          this.typeLink = 'إنشاء جديد';
        }
      }
    );
  }

    //get value date from child component 
    public getDate(date: any):void {
      console.log( date);
      this.higriDateVal = date.year + '-' + date.month + '-' + date.day;
      console.log('higrii date', this.higriDateVal);
    }
  

  //submitted form
  onSubmitted() {
    this.checkSaveClick = true;
    console.log(this.eventForm.value);
    this.eventForm.value['date'] = this.higriDateVal;
    this.eventForm.value.event_time = this.eventForm.value.date + this.eventForm.value.time;
    delete this.eventForm.value.time;

    console.log(this.eventForm.value); 
    if(this.typeMode) {
      this.eventService.editEvent(this.eventForm.value , this.eventId).subscribe(
        (responce) => {
          console.log(responce);
          this.toastr.success('تمت التعديل بنجاح');
          this.location.back();
          this.checkSaveClick = false;
        },
        (error) => {
          this.toastr.error('حدث خطأ !');
          console.log(error);
          this.checkSaveClick = false;
        }
      );
    } else {
      this.eventService.addEvent(this.eventForm.value).subscribe(
        (responce) => {
          console.log(responce);
          this.toastr.success('تمت الاضافه بنجاح');
          this.location.back();
          this.checkSaveClick = false;
        },
        (error) => {
          this.toastr.error('حدث خطأ !');
          console.log(error);
          this.checkSaveClick = false;
        }
      );
    }
  }

}
